package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.IpAddressResources;

/**
 * IP地址资源Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IIpAddressResourcesService 
{
    /**
     * 查询IP地址资源
     * 
     * @param id IP地址资源主键
     * @return IP地址资源
     */
    public IpAddressResources selectIpAddressResourcesById(Integer id);

    /**
     * 查询IP地址资源列表
     * 
     * @param ipAddressResources IP地址资源
     * @return IP地址资源集合
     */
    public List<IpAddressResources> selectIpAddressResourcesList(IpAddressResources ipAddressResources);

    /**
     * 新增IP地址资源
     * 
     * @param ipAddressResources IP地址资源
     * @return 结果
     */
    public int insertIpAddressResources(IpAddressResources ipAddressResources);

    /**
     * 修改IP地址资源
     * 
     * @param ipAddressResources IP地址资源
     * @return 结果
     */
    public int updateIpAddressResources(IpAddressResources ipAddressResources);

    /**
     * 批量删除IP地址资源
     * 
     * @param ids 需要删除的IP地址资源主键集合
     * @return 结果
     */
    public int deleteIpAddressResourcesByIds(Integer[] ids);

    /**
     * 删除IP地址资源信息
     * 
     * @param id IP地址资源主键
     * @return 结果
     */
    public int deleteIpAddressResourcesById(Integer id);
}
